==> rc-ui-lib-1.3.4.tgz: package/es/lazyload/utils/useEventVisible.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import { useEffect, useRef, useState } from 'react';
import { debounce as debounceFunc, DEFAULT_EVENTS, throttle as throttleFunc } from '.';
// try to handle passive events
var passiveEventSupported = false;

try {
  var opts = Object.defineProperty({}, 'passive', {
    get: function get() {
      passiveEventSupported = true;
    }
  });
  window.addEventListener('test', null, opts); // eslint-disable-next-line no-empty
} catch (e) {}

var passiveEvent = passiveEventSupported ? {
  capture: false,
  passive: true
} : false;

var useEventVisible = function useEventVisible(eventOptions) {
  var _eventOptions$listenE = eventOptions.listenEvents,
      listenEvents = _eventOptions$listenE === void 0 ? DEFAULT_EVENTS : _eventOptions$listenE,
      offset = eventOptions.offset,
      scrollContainer = eventOptions.scrollContainer,
      debounce = eventOptions.debounce,
      throttle = eventOptions.throttle; // 是否可见

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      visible = _useState2[0],
      setVisible = _useState2[1]; // // 包裹容器


  var containerRef = useRef(null);
  useEffect(function () {
    // 检查函数
    var _checkVisible = function checkVisible() {
      var _containerRef$current2;

      // 如果容器不存在则不计算
      if (!containerRef.current) return; // 获取当前组件位置

      var _containerRef$current = (_containerRef$current2 = containerRef.current) === null || _containerRef$current2 === void 0 ? void 0 : _containerRef$current2.getBoundingClientRect(),
          top = _containerRef$current.top,
          left = _containerRef$current.left,
          width = _containerRef$current.width,
          height = _containerRef$current.height; // 获取滚动容器位置


      var _scrollContainer$getB = scrollContainer.getBoundingClientRect(),
          parentTop = _scrollContainer$getB.top,
          parentLeft = _scrollContainer$getB.left,
          parentWidth = _scrollContainer$getB.width,
          parentHeight = _scrollContainer$getB.height; // 计算屏幕高度和宽度


      var windowInnerHeight = window.innerHeight || document.documentElement.clientHeight;
      var windowInnerWidth = window.innerWidth || document.documentElement.clientWidth; // 计算滚动容器和屏幕可视区的相交区域

      var intersectionTop = Math.min(parentTop, 0);
      var intersectionLeft = Math.min(parentLeft, 0);
      var intersectionHeight = Math.min(windowInnerHeight, parentTop + parentHeight) - intersectionTop;
      var intersectionWidth = Math.min(windowInnerWidth, parentLeft + parentWidth) - intersectionLeft; // 计算组件距离可视区的高度

      var offsetTop = top - intersectionTop;
      var offsetLeft = left - intersectionLeft; // 偏移量计算[top, left]

      var offsets = Array.isArray(offset) ? offset : [offset, offset]; // 通过上述距离判断组件是否在可见区域

      var isVisible = offsetTop - offsets[0] <= intersectionHeight && offsetTop + height + offsets[0] >= 0 && offsetLeft - offsets[1] <= intersectionWidth && offsetLeft + width + offsets[1] >= 0;
      setVisible(isVisible); // 如果可见取消当前组件的所有的监听

      if (isVisible) {
        listenEvents.forEach(function (event) {
          scrollContainer === null || scrollContainer === void 0 ? void 0 : scrollContainer.removeEventListener(event, _checkVisible);
        });
      }
    }; // 使用防抖节流增强checkVisible函数，这里优先防抖，其次节流


    if (debounce) {
      // 防抖函数
      _checkVisible = debounceFunc(_checkVisible, debounce);
    } else if (throttle) {
      // 节流函数
      _checkVisible = throttleFunc(_checkVisible, throttle);
    } // 批量监听事件


    listenEvents.forEach(function (event) {
      scrollContainer === null || scrollContainer === void 0 ? void 0 : scrollContainer.addEventListener(event, _checkVisible, passiveEvent);
    }); // 自动执行一次

    _checkVisible();

    return function () {
      listenEvents.forEach(function (event) {
        scrollContainer === null || scrollContainer === void 0 ? void 0 : scrollContainer.removeEventListener(event, _checkVisible, passiveEvent);
      });
    };
  }, [scrollContainer]);
  return [containerRef, visible];
};

export default useEventVisible;

==> rc-ui-lib-1.3.5.tgz: package/es/lazyload/utils/useEventVisible.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import { useEffect, useRef, useState } from 'react';
import { debounce as debounceFunc, DEFAULT_EVENTS, throttle as throttleFunc } from '.';
// try to handle passive events
var passiveEventSupported = false;
try {
  var opts = Object.defineProperty({}, 'passive', {
    get: function get() {
      passiveEventSupported = true;
    }
  });
  window.addEventListener('test', null, opts);
  // eslint-disable-next-line no-empty
} catch (e) {}
var passiveEvent = passiveEventSupported ? {
  capture: false,
  passive: true
} : false;
var useEventVisible = function useEventVisible(eventOptions) {
  var _eventOptions$listenE = eventOptions.listenEvents,
    listenEvents = _eventOptions$listenE === void 0 ? DEFAULT_EVENTS : _eventOptions$listenE,
    offset = eventOptions.offset,
    scrollContainer = eventOptions.scrollContainer,
    debounce = eventOptions.debounce,
    throttle = eventOptions.throttle;
  // 是否可见
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    visible = _useState2[0],
    setVisible = _useState2[1];
  // // 包裹容器
  var containerRef = useRef(null);
  useEffect(function () {
    // 检查函数
    var _checkVisible = function checkVisible() {
      var _containerRef$current2;
      // 如果容器不存在则不计算
      if (!containerRef.current) return;
      // 获取当前组件位置
      var _containerRef$current = (_containerRef$current2 = containerRef.current) === null || _containerRef$current2 === void 0 ? void 0 : _containerRef$current2.getBoundingClientRect(),
        top = _containerRef$current.top,
        left = _containerRef$current.left,
        width = _containerRef$current.width,
        height = _containerRef$current.height;
      // 获取滚动容器位置
      var _scrollContainer$getB = scrollContainer.getBoundingClientRect(),
        parentTop = _scrollContainer$getB.top,
        parentLeft = _scrollContainer$getB.left,
        parentWidth = _scrollContainer$getB.width,
        parentHeight = _scrollContainer$getB.height;
      // 计算屏幕高度和宽度
      var windowInnerHeight = window.innerHeight || document.documentElement.clientHeight;
      var windowInnerWidth = window.innerWidth || document.documentElement.clientWidth;
      // 计算滚动容器和屏幕可视区的相交区域
      var intersectionTop = Math.min(parentTop, 0);
      var intersectionLeft = Math.min(parentLeft, 0);
      var intersectionHeight = Math.min(windowInnerHeight, parentTop + parentHeight) - intersectionTop;
      var intersectionWidth = Math.min(windowInnerWidth, parentLeft + parentWidth) - intersectionLeft;
      // 计算组件距离可视区的高度
      var offsetTop = top - intersectionTop;
      var offsetLeft = left - intersectionLeft;
      // 偏移量计算[top, left]
      var offsets = Array.isArray(offset) ? offset : [offset, offset];
      // 通过上述距离判断组件是否在可见区域
      var isVisible = offsetTop - offsets[0] <= intersectionHeight && offsetTop + height + offsets[0] >= 0 && offsetLeft - offsets[1] <= intersectionWidth && offsetLeft + width + offsets[1] >= 0;
      setVisible(isVisible);
      // 如果可见取消当前组件的所有的监听
      if (isVisible) {
        listenEvents.forEach(function (event) {
          scrollContainer === null || scrollContainer === void 0 ? void 0 : scrollContainer.removeEventListener(event, _checkVisible);
        });
      }
    };

    // 使用防抖节流增强checkVisible函数，这里优先防抖，其次节流
    if (debounce) {
      // 防抖函数
      _checkVisible = debounceFunc(_checkVisible, debounce);
    } else if (throttle) {
      // 节流函数
      _checkVisible = throttleFunc(_checkVisible, throttle);
    }
    // 批量监听事件
    listenEvents.forEach(function (event) {
      scrollContainer === null || scrollContainer === void 0 ? void 0 : scrollContainer.addEventListener(event, _checkVisible, passiveEvent);
    });

    // 自动执行一次
    _checkVisible();
    return function () {
      listenEvents.forEach(function (event) {
        scrollContainer === null || scrollContainer === void 0 ? void 0 : scrollContainer.removeEventListener(event, _checkVisible, passiveEvent);
      });
    };
  }, [scrollContainer]);
  return [containerRef, visible];
};
export default useEventVisible;
